@@ -27,7 +27,8 @@ pub fn create_instance(bot_token: &str, chat_id: &str) -> BotInstance {
 ///
 /// * `instance` - `BotInstance` to send message to telegram's chat
 /// * `msg` - message to send
-pub fn send_message(instance: &BotInstance, msg: &str) -> Result<(), ErrorResult> {
+/// * `options` - options for sending message
+pub fn send_message(instance: &BotInstance, msg: &str, options: Option<SendMessageOption>) -> Result<(), ErrorResult> {
     let raw_url_str = format!("https://api.telegram.org/bot{}/sendMessage", instance.bot_token);
     let url = match Url::parse(&raw_url_str) {
 		Ok(res) => res,
@@ -40,12 +41,17 @@ pub fn send_message(instance: &BotInstance, msg: &str) -> Result<(), ErrorResult
     struct RequestObj<'a> {
         chat_id: &'a str,
         text: &'a str,
+
+        // this is required unfortunately, see https://github.com/serde-rs/serde/issues/947
+        #[serde(skip_serializing_if = "Option::is_none")]
+        parse_mode: Option<&'a str>,
     }
 
     // create a request object which contains parameters needed for the API
     let request_json_obj = RequestObj {
         chat_id: &instance.chat_id,
         text: msg,
+        parse_mode: if options.is_some() && options.as_ref().unwrap().parse_mode.is_some() { Some(utils::get_send_message_parse_mode_str(options.unwrap().parse_mode.unwrap())) } else { None }
     };
 
     // serialize as json byte vector
@@ -91,7 +97,8 @@ pub fn send_message(instance: &BotInstance, msg: &str) -> Result<(), ErrorResult
 ///
 /// * `instance` - `BotInstance` to send message to telegram's chat
 /// * `msg` - message to send
-pub async fn send_message_async(instance: &BotInstance, msg: &str) -> Result<(), ErrorResult> {
+/// * `options` - options for sending message
+pub async fn send_message_async(instance: &BotInstance, msg: &str, options: Option<SendMessageOption>) -> Result<(), ErrorResult> {
     let raw_url_str = format!("https://api.telegram.org/bot{}/sendMessage", instance.bot_token);
     let url = match Url::parse(&raw_url_str) {
 		Ok(res) => res,
@@ -104,12 +111,17 @@ pub async fn send_message_async(instance: &BotInstance, msg: &str) -> Result<(),
     struct RequestObj<'a> {
         chat_id: &'a str,
         text: &'a str,
+
+        // this is required unfortunately, see https://github.com/serde-rs/serde/issues/947
+        #[serde(skip_serializing_if = "Option::is_none")]
+        parse_mode: Option<&'a str>,
     }
 
     // create a request object which contains parameters needed for the API
     let request_json_obj = RequestObj {
         chat_id: &instance.chat_id,
         text: msg,
+        parse_mode: if options.is_some() && options.as_ref().unwrap().parse_mode.is_some() { Some(utils::get_send_message_parse_mode_str(options.unwrap().parse_mode.unwrap())) } else { None }
     };
 
     // serialize as json byte vector
